@@ -326,8 +326,8 @@
  * How to jump to the end of the current function quickly?
 
    1. Move cursor to the function below marked -->.
-   2. Type \\[meow-bounds-of-thing] and \"c\", then \"a\".
-
+   2. Type \\[meow-bounds-of-thing] and \"c\", then \\[meow-append].
+  
    -->
    fn count_ones(mut n: i64) -> usize {
     let mut count: usize = 0;
@@ -338,7 +338,7 @@
     count
    }
 
- Note that Meow need the major mode for the programming language
+ Note that Meow needs the major mode for the programming language
  to find functions correctly. Then if you type \\[meow-bounds-of-thing] and \"d\" to
  select the whole function here, it won't work. Go to your
  favorite programming language mode and practice!
@@ -509,7 +509,7 @@
         [| \"1\" |] [| \"2\" |] [| \"3\" |]
 
  1. Move the cursor to the line below marked -->
- 2. Select the whole line (you know how to do this)
+ 2. Select the \"1 2 3\"
  3. Press \\[meow-grab] to grab the selection
  4. Press \\[meow-back-word] to create fake cursors at the beginning of each word
     in the backwards direction.
@@ -569,7 +569,7 @@
        added to your search if the selection is created with \\[meow-visit], \\[meow-mark-word] and \\[meow-mark-symbol].
 
 =================================================================
-=                    KEYPAD AND MOTION MODE                     =
+=                    KEYPAD                                     =
 =================================================================
 
  One of the most notable features of Meow is the Keypad. It
@@ -644,9 +644,6 @@
       (insert (format (substitute-command-keys meow--tutor-content)
                       (alist-get 'normal meow-replace-state-name-list)
                       (alist-get 'insert meow-replace-state-name-list)))
-      (setq-local scroll-conservatively 1)
-      (setq-local scroll-margin 3)
-      (setq-local scroll-step 1)
       (goto-char (point-min))
       (display-line-numbers-mode))
     (switch-to-buffer buf)))
